# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/help/legit/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Help\\Legit\\": "packages/help/legit/src",
            "Help\\Legit\\Seeders\\": "packages/help/legit/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Help\Legit\Providers\LegitServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Legit'  => Help\Legit\Facades\Legit::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Help\\Legit\\Seeders\\LegitTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Help\Legit\Providers\LegitServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Help\Legit\Providers\LegitServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Help\Legit\Providers\LegitServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/legit/{modulename}

**User**

    http://path-to-route-folder/user/legit/{modulename}

**Public**

    http://path-to-route-folder/legits


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/legit/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/legit/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/legit/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/legit/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/legit/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/legit/{modulename}/{slug}
    METHOD: GET